@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Play the tabla!
 
-our $VERSION = '0.0602';
+our $VERSION = '0.0603';
 
 use Moo;
 use File::ShareDir qw(dist_dir);
@@ -159,7 +159,7 @@ Music::Percussion::Tabla - Play the tabla!
 
 =head1 VERSION
 
-version 0.0602
+version 0.0603
 
 =head1 SYNOPSIS
 
@@ -167,29 +167,25 @@ version 0.0602
 
   my $t = Music::Percussion::Tabla->new;
 
-  $t->timidity_cfg('/tmp/timidity.cfg'); # optional
-
-  say $t->soundfont;
-
   for (1 .. $t->bars) {
     $t->strike('ta', $t->eighth);
     $t->strike('ta', $t->eighth);
-    $t->strike('tun');
+    $t->strike('dha');
     $t->strike('ge');
     $t->rest($t->quarter);
   }
 
-  $t->strike('dha', $t->quarter);
-
-  $t->teentaal($t->eighth) for 1 .. $t->bars;
-  $t->keherawa($t->eighth) for 1 .. $t->bars;
-  $t->jhaptaal($t->eighth) for 1 .. $t->bars;
-  $t->dadra($t->eighth) for 1 .. $t->bars;
+  $t->teentaal($t->eighth)  for 1 .. $t->bars;
+  $t->keherawa($t->eighth)  for 1 .. $t->bars;
+  $t->jhaptaal($t->eighth)  for 1 .. $t->bars;
+  $t->dadra($t->eighth)     for 1 .. $t->bars;
   $t->rupaktaal($t->eighth) for 1 .. $t->bars;
 
   $t->play_with_timidity;
   # OR:
   $t->write; # save the score as a MIDI file
+  $t->timidity_cfg('/Users/you/timidity.cfg');
+  # then run timidity with that config and MIDI file
 
 =head1 DESCRIPTION
 
@@ -256,7 +252,7 @@ Default: C<dist_dir()/Tabla.sf2>
 
 Each bol can be 1 or more patch numbers.
 
-Default bol patches:
+Default single strike bol patches:
 
   ga:   65
   ge:   66 76
@@ -267,6 +263,13 @@ Default bol patches:
   tin:  60 63 83 87
   tun:  88
 
+Default double strike bols:
+
+  dha:  ge ta
+  dhin: ge tin
+  dhit: ge ti
+  dhun: ge tun
+
 =head1 METHODS
 
 =head2 new
@@ -284,23 +287,26 @@ constructor attributes of L<MIDI::Drummer::Tiny>.
   $tabla->strike($bol, $duration);
   $tabla->strike($bol, $duration, $patch);
 
-Single strike bols:
+This method handles two types of strikes: single and double.
 
-  ga, ge, ke, na, ta, ti, tin, tun
+A named B<bol> can have one or more B<patches> associated with it. For
+single strikes, calling with a specific B<patch> will play that patch,
+of course. Calling the method with either no B<patch> or a B<patch> of
+C<-1> will play one of the B<bol> patches at random.
 
 The B<duration> is a note length like C<$tabla-E<gt>eighth> (or
 C<'en'> in MIDI-Perl notation).
 
-Each bol can be 1 or more patch numbers. For bols with more than one
-patch possibility, calling that method with either no B<patch> or a
-B<patch> of C<-1> will play one of the patches at random.
+1. Single strike bols:
 
-Double strike bols:
+  ga, ge, ke, na, ta, ti, tin, tun
+
+2. Double strike bols:
 
   dha, dhin, dhit, dhun
 
-Play a double-strike on the B<baya> and B<daya> drums for the given
-B<bol> and B<duration>.
+For a double strike, play on both the baya and daya drums for the
+given B<bol> and B<duration>.
 
 Patches given for double-strikes will be ignored. That is, each of the
 individual bols comprising the double-strike are chosen at random. If
